@@ -1,4 +1,5 @@
 import os
+import base64
 
 from aloft.process import execute
 from aloft import aws
@@ -6,6 +7,7 @@ from aloft import k8s
 from aloft import chart_config
 from aloft import output
 from aloft import volume
+from tempfile import NamedTemporaryFile
 
 
 def apply_charts(release_id, chart_set, charts, sandbox_name, options):
@@ -97,26 +99,63 @@ def get_release_name(chart, namespace):
 
 
 def create_secrets(chart, secrets_config, namespace):
-    secret_args = ''
-    secret_keys = []
 
     if secrets_config:
+        create_standard_secrets(secrets_config, chart, namespace)
+        create_docker_secrets(secrets_config, namespace)
+
+
+def create_standard_secrets(secrets_config, chart, namespace):
+    secret_args = ''
+    secret_keys = []
+    temp_filenames = []
+
+    try:
         for item in secrets_config.get('items', []):
             vault_key = item.get('vaultKey', None)
             secret_key = item.get('secretKey', None)
+            encoded = item.get('encoded', False)
 
             if secret_key:
                 secret_keys.append(secret_key)
                 secret_value = aws.get_secret(vault_key)
 
                 if secret_value:
-                    secret_args = f'{secret_args} --from-literal={secret_key}={secret_value}'
+                    if encoded:
+                        secret_value = base64.standard_b64decode(secret_value).decode('utf-8')
+
+                    temp_file = NamedTemporaryFile(mode='w+t', delete=False)
+                    temp_file.write(secret_value)
+                    temp_file.flush()
+                    temp_filenames.append(temp_file.name)
+                    secret_args = f'{secret_args} --from-file={secret_key}={temp_file.name}'
 
         if secret_args:
             secrets_name = secrets_config.get('secretName', f'{chart}-secret')
             output.print_action(f'Creating secret {secrets_name} with keys {secret_keys}')
-            execute(f'kubectl -n {namespace} delete secret {secrets_name}', ['NotFound'], quiet=True)
-            execute(f'kubectl -n {namespace} create secret generic {secrets_name} {secret_args}', quiet=True)
+            execute(f'kubectl -n {namespace} delete secret {secrets_name}', ['NotFound'], quiet=False)
+            execute(f'kubectl -n {namespace} create secret generic {secrets_name} {secret_args}', quiet=False)
+
+    finally:
+        if temp_filenames:
+            rm_args = ' '.join(temp_filenames)
+            execute(f'rm -f {rm_args}')
+
+
+def create_docker_secrets(secrets_config, namespace):
+    for secret in secrets_config.get('dockerRegistrySecrets', []):
+        vault_username_key = secret.get('vaultUsernameKey', None)
+        vault_password_key = secret.get('vaultPasswordKey', None)
+
+        docker_username = aws.get_secret(vault_username_key)
+        docker_password = aws.get_secret(vault_password_key)
+
+        output.print_action(f'Creating docker-registry secret {secret["secretName"]}'
+                            f' with username {vault_username_key} and password {vault_password_key}')
+        execute(f'kubectl -n {namespace} delete secret {secret["secretName"]}', ['NotFound'], quiet=True)
+        execute(f'kubectl -n {namespace} create secret docker-registry {secret["secretName"]}'
+                f' --docker-server={secret["dockerServer"]} --docker-username={docker_username}'
+                f' --docker-password={docker_password} --docker-email={secret["dockerEmail"]}', quiet=True)
 
 
 def delete_secrets(chart, secrets_config, namespace):
@@ -124,6 +163,9 @@ def delete_secrets(chart, secrets_config, namespace):
         secrets_name = secrets_config.get('secretName', f'{chart}-secret')
         execute(f'kubectl -n {namespace} delete secret {secrets_name}', ['NotFound'])
 
+        for secret in secrets_config.get('dockerRegistrySecrets', []):
+            execute(f'kubectl -n {namespace} delete secret {secret["secretName"]}', ['NotFound'])
+
 
 def execute_install_hook(hook_type, chart_directory):
     hook_script = f'{chart_directory}/hooks/{hook_type}'
