@@ -122,8 +122,15 @@ def get_state_store_locator(vpc_id):
 
 
 def get_state_store_name(vpc_id):
-    return f'k8s-state.{vpc_id}'
+    state_store = f'k8s-state.{vpc_id}'
+    bucket_name = get_state_store_bucket()
+    return state_store if bucket_name is None else f'{bucket_name}/{state_store}'
 
+def get_state_store_bucket():
+    try:
+     return os.environ['AWS_STATE_STORE_BUCKET']
+    except KeyError:
+        return None
 
 def assume_role_by_cluster_id(cluster_id):
     vpc_id = get_vpc_id_by_cluster_id(cluster_id)
@@ -252,7 +259,8 @@ def validate_cluster(cluster_id):
 
 
 def create_cluster_and_apply_system(cluster_id, options):
-    with kubeconfig(f'~/.kube/config.{cluster_id}') as config:
+    home = os.environ['HOME']
+    with kubeconfig(f'{home}/.kube/config.{cluster_id}') as config:
         conditionally_create_vpc_and_cluster(cluster_id, options)
         chart.apply_charts(cluster_id, 'system', ['system'], None, options)
     use_cluster(cluster_id)
