@@ -1,4 +1,5 @@
 import copy
+import time
 from aloft import aws
 from aloft import cluster
 from aloft import chart_config
@@ -173,12 +174,29 @@ def get_aws_volume_resource_id(persistent_volume):
 def get_chart_persistent_volume_names(chart, namespace):
     resource_name = f'{namespace}-{chart}'
     select_by_release_name = [{'key': 'release', 'value': resource_name, 'operator': '='}]
-    persistent_volume_claims = k8s.get_resources('pvc', namespace, select_by_release_name)
+    all_volumes_found = False
     persistent_volume_names = []
+    volume_not_found_count = 0
 
-    for persistent_volume_claim in persistent_volume_claims:
-        persistent_volume_name = persistent_volume_claim['spec']['volumeName']
-        persistent_volume_names.append(persistent_volume_name)
+    while not all_volumes_found:
+        persistent_volume_claims = k8s.get_resources('pvc', namespace, select_by_release_name)
+        missing_volume_names = []
+
+        for persistent_volume_claim in persistent_volume_claims:
+            persistent_volume_name = persistent_volume_claim['spec'].get('volumeName')
+            if persistent_volume_name:
+                persistent_volume_names.append(persistent_volume_name)
+            else:
+                missing_volume_names.append(persistent_volume_claim['metadata']['name'])
+
+        if len(missing_volume_names) == 0:
+            all_volumes_found = True
+        else:
+            time.sleep(2)
+            volume_not_found_count += 1
+
+        if volume_not_found_count > 10:
+            raise RuntimeError(f'Unable to retrieve persistent volume names for: {", ".join(missing_volume_names)}')
 
     return persistent_volume_names
 
